==> owncloud-5.0.17.tar.bz2: owncloud/apps/calendar/l10n/zh_CN.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "日程表未全部缓存完成",
"Everything seems to be completely cached" => "貌似所有事务已被缓存",
"No calendars found." => "无法找到日历。",
"No events found." => "无法找到事件。",
"Wrong calendar" => "错误的日历",
"You do not have the permissions to edit this event." => "您没有权限编辑此日历",
"The file contained either no events or all events are already saved in your calendar." => "文件中不含事件，或者所有事件已保存到日历中。",
"events has been saved in the new calendar" => "事件已被保存到新日历",
"Import failed" => "导入失败",
"events has been saved in your calendar" => "事件已被保存到您的日历",
"New Timezone:" => "新时区：",
"Timezone changed" => "时区已修改",
"Invalid request" => "非法请求",
"Calendar" => "日历",
"Deletion failed" => "删除失败",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"user" => "用户",
"group" => "组",
"Editable" => "可编辑",
"Shareable" => "可共享",
"Deletable" => "可删除",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "星期日",
"Monday" => "星期一",
"Tuesday" => "星期二",
"Wednesday" => "星期三",
"Thursday" => "星期四",
"Friday" => "星期五",
"Saturday" => "星期六",
"Sun." => "星期天",
"Mon." => "星期一",
"Tue." => "星期二",
"Wed." => "星期三",
"Thu." => "星期四",
"Fri." => "星期五",
"Sat." => "星期六",
"January" => "一月",
"February" => "二月",
"March" => "三月",
"April" => "四月",
"May" => "五月",
"June" => "六月",
"July" => "七月",
"August" => "八月",
"September" => "九月",
"October" => "十月",
"November" => "十一月",
"December" => "十二月",
"Jan." => "一月",
"Feb." => "二月",
"Mar." => "三月",
"Apr." => "四月",
"May." => "五月",
"Jun." => "六月",
"Jul." => "七月",
"Aug." => "八月",
"Sep." => "九月",
"Oct." => "十月",
"Nov." => "十一月",
"Dec." => "十二月",
"All day" => "全天",
"New Calendar" => "新日历",
"Missing or invalid fields" => "缺少或无效的字段",
"Title" => "标题",
"From Date" => "从",
"From Time" => "从",
"To Date" => "至",
"To Time" => "至",
"The event ends before it starts" => "事件在开始前已结束",
"There was a database fail" => "数据库访问失败",
"Birthday" => "生日",
"Business" => "商务",
"Call" => "呼叫",
"Clients" => "客户",
"Deliverer" => "供应商",
"Holidays" => "节日",
"Ideas" => "想法",
"Journey" => "旅行",
"Jubilee" => "周年纪念",
"Meeting" => "会议",
"Other" => "其他",
"Personal" => "个人",
"Projects" => "项目",
"Questions" => "问题",
"Work" => "工作",
"by" => "被",
"unnamed" => "未命名",
"You do not have the permissions to update this calendar." => "您没有权限更新此日历",
"You do not have the permissions to delete this calendar." => "您没有权限删除此日历",
"You do not have the permissions to add to this calendar." => "您没有权限增加到此日历",
"You do not have the permissions to add events to this calendar." => "您没有权限增加事项到此日历",
"You do not have the permissions to delete this event." => "您没有权限删除此事件",
"Busy" => "忙碌",
"Public" => "公共",
"Private" => "私人",
"Confidential" => "证书",
"Does not repeat" => "不重复",
"Daily" => "每天",
"Weekly" => "每周",
"Every Weekday" => "每个工作日",
"Bi-Weekly" => "每两周",
"Monthly" => "每月",
"Yearly" => "每年",
"never" => "从不",
"by occurrences" => "按发生次数",
"by date" => "按日期",
"by monthday" => "按月的某天",
"by weekday" => "按星期的某天",
"events week of month" => "事件在每月的第几个星期",
"first" => "第一",
"second" => "第二",
"third" => "第三",
"fourth" => "第四",
"fifth" => "第五",
"last" => "最后",
"by events date" => "按事件日期",
"by yearday(s)" => "按每年的某天",
"by weeknumber(s)" => "按星期数",
"by day and month" => "按天和月份",
"Date" => "日期",
"Cal." => "日历",
"Week" => "星期",
"Month" => "月",
"List" => "列表",
"Today" => "今天",
"Settings" => "设置",
"Your calendars" => "您的日历",
"CalDav Link" => "CalDav 链接",
"Share Calendar" => "共享日历",
"Download" => "下载",
"Edit" => "编辑",
"Delete" => "删除",
"New calendar" => "新日历",
"Edit calendar" => "编辑日历",
"Displayname" => "显示名称",
"Active" => "活动",
"Calendar color" => "日历颜色",
"Save" => "保存",
"Submit" => "提交",
"Cancel" => "取消",
"Edit an event" => "编辑事件",
"Export" => "导出",
"Eventinfo" => "事件信息",
"Repeating" => "重复",
"Alarm" => "提醒",
"Attendees" => "参加者",
"Share" => "共享",
"Title of the Event" => "事件标题",
"Category" => "分类",
"Separate categories with commas" => "用逗号分隔分类",
"Edit categories" => "编辑分类",
"Access Class" => "访问分类",
"All Day Event" => "全天事件",
"From" => "自",
"To" => "至",
"Advanced options" => "高级选项",
"Location" => "地点",
"Location of the Event" => "事件地点",
"Description" => "描述",
"Description of the Event" => "事件描述",
"Repeat" => "重复",
"Advanced" => "高级",
"Select weekdays" => "选择星期中的某天",
"Select days" => "选择某天",
"and the events day of year." => "选择每年事件发生的日子",
"and the events day of month." => "选择每月事件发生的日子",
"Select months" => "选择月份",
"Select weeks" => "选择星期",
"and the events week of year." => "选择每年的事件发生的星期",
"Interval" => "间隔",
"End" => "结束",
"occurrences" => "次",
"create a new calendar" => "创建新日历",
"Import a calendar file" => "导入日历文件",
"Please choose a calendar" => "请选择日历",
"Name of new calendar" => "新日历名称",
"Take an available name!" => "使用有效名称！",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "已有日历使用此名称。如果您执意继续，这些日历将会合并。",
"Remove all events from the selected calendar" => "从选定的日历中删除所有事件",
"Import" => "导入",
"Close Dialog" => "关闭对话框",
"Create a new event" => "创建新事件",
"Share with:" => "共享人",
"Shared with" => "已共享给",
"Unshare" => "取消共享",
"Nobody" => "没有人",
"Shared via calendar" => "通过日历分享",
"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "备注：处理通过日历共享的事件将会影响整个日历共享项",
"View an event" => "查看事件",
"No categories selected" => "无选中分类",
"of" => "在",
"at" => "在",
"General" => "常规",
"Timezone" => "时区",
"Update timezone automatically" => "自动更新时区",
"Time format" => "时间格式",
"24h" => "24小时",
"12h" => "12小时",
"Start week on" => "一周开始于",
"Cache" => "缓存",
"Clear cache for repeating events" => "清理重复事件的缓存",
"URLs" => "网址",
"Calendar CalDAV syncing addresses" => "日历 CalDAV 同步地址",
"more info" => "更多信息",
"Primary address (Kontact et al)" => "主地址",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => "只读 iCanlendar 连接"
);

==> owncloud_7.0.11~dfsg.orig.tar.bz2: owncloud/apps/calendar/l10n/zh_CN.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "日程表未全部缓存完成",
"Everything seems to be completely cached" => "貌似所有事务已被缓存",
"No calendars found." => "无法找到日历。",
"No events found." => "无法找到事件。",
"Wrong calendar" => "错误的日历",
"You do not have the permissions to edit this event." => "您没有权限编辑此日历",
"The file contained either no events or all events are already saved in your calendar." => "文件中不含事件，或者所有事件已保存到日历中。",
"Import failed" => "导入失败",
"New Timezone:" => "新时区：",
"Timezone changed" => "时区已修改",
"Invalid request" => "非法请求",
"Calendar" => "日历",
"Deletion failed" => "删除失败",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"group" => "组",
"can edit" => "可编辑",
"can share" => "可共享",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '–'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "星期日",
"Monday" => "星期一",
"Tuesday" => "星期二",
"Wednesday" => "星期三",
"Thursday" => "星期四",
"Friday" => "星期五",
"Saturday" => "星期六",
"Sun." => "星期天",
"Mon." => "星期一",
"Tue." => "星期二",
"Wed." => "星期三",
"Thu." => "星期四",
"Fri." => "星期五",
"Sat." => "星期六",
"January" => "一月",
"February" => "二月",
"March" => "三月",
"April" => "四月",
"May" => "五月",
"June" => "六月",
"July" => "七月",
"August" => "八月",
"September" => "九月",
"October" => "十月",
"November" => "十一月",
"December" => "十二月",
"Jan." => "一月",
"Feb." => "二月",
"Mar." => "三月",
"Apr." => "四月",
"May." => "五月",
"Jun." => "六月",
"Jul." => "七月",
"Aug." => "八月",
"Sep." => "九月",
"Oct." => "十月",
"Nov." => "十一月",
"Dec." => "十二月",
"All day" => "全天",
"New Calendar" => "新日历",
"Missing or invalid fields" => "缺少或无效的字段",
"Title" => "标题",
"From Date" => "从",
"From Time" => "从",
"To Date" => "至",
"To Time" => "至",
"The event ends before it starts" => "事件在开始前已结束",
"There was a database fail" => "数据库访问失败",
"Birthday" => "生日",
"Business" => "商务",
"Call" => "呼叫",
"Clients" => "客户",
"Deliverer" => "供应商",
"Holidays" => "节日",
"Ideas" => "想法",
"Journey" => "旅行",
"Jubilee" => "周年纪念",
"Meeting" => "会议",
"Other" => "其他",
"Personal" => "个人",
"Projects" => "项目",
"Questions" => "问题",
"Work" => "工作",
"by" => "被",
"unnamed" => "未命名",
"You do not have the permissions to update this calendar." => "您没有权限更新此日历",
"You do not have the permissions to delete this calendar." => "您没有权限删除此日历",
"You do not have the permissions to add to this calendar." => "您没有权限增加到此日历",
"You do not have the permissions to add events to this calendar." => "您没有权限增加事项到此日历",
"You cannot add non-public events to a shared calendar." => "你不能增加非公共的事件到共享的日程表",
"You do not have the permissions to delete this event." => "您没有权限删除此事件",
"Busy" => "忙碌",
"Show full event" => "显示完整事件",
"Show only busy" => "仅显示繁忙",
"Hide event" => "隐藏事件",
"Does not repeat" => "不重复",
"Daily" => "每天",
"Weekly" => "每周",
"Every Weekday" => "每个工作日",
"Bi-Weekly" => "每两周",
"Monthly" => "每月",
"Yearly" => "每年",
"never" => "从不",
"by occurrences" => "按发生次数",
"by date" => "按日期",
"by monthday" => "按月的某天",
"by weekday" => "按星期的某天",
"events week of month" => "事件在每月的第几个星期",
"first" => "第一",
"second" => "第二",
"third" => "第三",
"fourth" => "第四",
"fifth" => "第五",
"last" => "最后",
"by events date" => "按事件日期",
"by yearday(s)" => "按每年的某天",
"by weeknumber(s)" => "按星期数",
"by day and month" => "按天和月份",
"Contact birthdays" => "联系人生日",
"Date" => "日期",
"Cal." => "日历",
"Day" => "天",
"Week" => "星期",
"Month" => "月",
"Today" => "今天",
"CalDav Link" => "CalDav 链接",
"Timezone" => "时区",
"Update timezone automatically" => "自动更新时区",
"Time format" => "时间格式",
"24h" => "24小时",
"12h" => "12小时",
"Start week on" => "一周开始于",
"Cache" => "缓存",
"Clear cache for repeating events" => "清理重复事件的缓存",
"Primary CalDAV address" => "主要的 CalDAV 地址",
"iOS/OS X CalDAV address" => "iOS/OS X CalDAV 地址",
"Share Calendar" => "共享日历",
"Download" => "下载",
"Edit" => "编辑",
"Delete" => "删除",
"New calendar" => "新日历",
"Edit calendar" => "编辑日历",
"Edit event" => "编辑事件",
"Save event" => "保存事件",
"Delete event" => "删除事件",
"Eventinfo" => "事件信息",
"Repeating" => "重复",
"Alarm" => "提醒",
"Attendees" => "参加者",
"Share" => "共享",
"Title of the Event" => "事件标题",
"from" => "来源",
"to" => "到",
"All Day Event" => "全天事件",
"Advanced options" => "高级选项",
"Location" => "地点",
"Categories (separate by comma)" => "类别(逗号分隔)",
"Edit categories" => "编辑分类",
"Description" => "描述",
"Export event" => "导出事件",
"Repeat" => "重复",
"Advanced" => "高级",
"Select weekdays" => "选择星期中的某天",
"Select days" => "选择某天",
"and the events day of year." => "选择每年事件发生的日子",
"and the events day of month." => "选择每月事件发生的日子",
"Select months" => "选择月份",
"Select weeks" => "选择星期",
"and the events week of year." => "选择每年的事件发生的星期",
"Interval" => "间隔",
"End" => "结束",
"occurrences" => "次",
"Visibility to people shared with" => "好友是否可见",
"create a new calendar" => "创建新日历",
"Import a calendar file" => "导入日历文件",
"Please choose a calendar" => "请选择日历",
"Name of new calendar" => "新日历名称",
"Take an available name!" => "使用有效名称！",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "已有日历使用此名称。如果您执意继续，这些日历将会合并。",
"Remove all events from the selected calendar" => "从选定的日历中删除所有事件",
"Import" => "导入",
"Close Dialog" => "关闭对话框",
"Create a new event" => "创建新事件",
"Create event" => "创建新事件",
"Share with user or group" => "分享给其他用户或组 ...",
"Unshare" => "取消共享",
"Not shared with anyone" => "不与任何人共享",
"Send Email" => "发送邮件",
"Shared via calendar" => "通过日历分享",
"Not shared with anyone via calendar" => "不通过日历与任何人共享",
"View an event" => "查看事件",
"Category" => "分类",
"No categories selected" => "无选中分类",
"%s of %s" => "%s / %s",
"Access Class" => "访问分类",
"From" => "自",
"at" => "在",
"To" => "至"
);
